@@ -24,9 +24,13 @@
 #' @param lambda Values of the regularization parameter \code{lambda} at which
 #' predictions are requested.  Linear interpolation is used for values of
 #' \code{lambda} not in the sequence of lambda values in the fitted models.
+#' @param k Index of the response to predict in multiple responses regression (
+#' \code{family="mgaussian"}).
 #' @param which Indices of the penalty parameter \code{lambda} at which
 #' predictions are required.  By default, all indices are returned.  If
 #' \code{lambda} is specified, this will override \code{which}.
+#' @param intercept Whether the intercept should be included in the returned
+#' coefficients. For \code{family="mgaussian"} only.
 #' @param drop If coefficients for a single value of \code{lambda} are to be
 #' returned, reduce dimensions to a vector?  Setting \code{drop=FALSE} returns
 #' a 1-column matrix.
@@ -60,7 +64,7 @@ predict.biglasso <- function(object, X, row.idx = 1:nrow(X),
   type <- match.arg(type)
   beta <- coef.biglasso(object, lambda=lambda, which=which, drop=FALSE)
   if (type=="coefficients") return(beta)
-  if (class(object)[1]=="biglasso") {
+  if (class(object)[1]=="biglasso" && object$family != "cox") {
     alpha <- beta[1,]
     beta <- beta[-1,,drop=FALSE]
   }
@@ -74,10 +78,10 @@ predict.biglasso <- function(object, X, row.idx = 1:nrow(X),
  
   beta.T <- as(beta, "dgTMatrix") 
   temp <- get_eta(X@address, as.integer(row.idx-1), beta, beta.T@i, beta.T@j)
-  eta <- sweep(temp, 2, alpha, "+")
+  if(object$family != "cox") eta <- sweep(temp, 2, alpha, "+")
   # dimnames(eta) <- list(c(1:nrow(eta)), round(object$lambda, digits = 4))
   
-  if (object$family == 'gaussian') {
+  if (object$family != 'binomial') {
     if (type == 'class') {
       stop("type='class' can only be used with family='binomial'")
     } else { ## then 'type' must be either 'link' or 'response'
@@ -94,6 +98,37 @@ predict.biglasso <- function(object, X, row.idx = 1:nrow(X),
   }
 }
 
+#' @method predict mbiglasso
+#' @rdname predict.biglasso
+#' @export
+#'
+predict.mbiglasso <- function(object, X, row.idx = 1:nrow(X), 
+                             type = c("link", "response", 
+                                      "coefficients", "vars", "nvars"),
+                             lambda, which = 1:length(object$lambda), k = 1, ...) {
+  type <- match.arg(type)
+  beta <- coef.biglasso(object, lambda=lambda, which=which, drop=FALSE)[[k]]
+  if (type=="coefficients") return(beta)
+  if (class(object)[1]=="biglasso") {
+    alpha <- beta[1,]
+    beta <- beta[-1,,drop=FALSE]
+  }
+  
+  if (type=="nvars") return(apply(beta!=0,2,sum, na.rm = T))
+  if (type=="vars") return(drop(apply(beta!=0, 2, FUN=which)))
+  
+  if (!inherits(X, 'big.matrix')) {
+    stop("X must be a big.matrix object.")
+  }
+  
+  beta.T <- as(beta, "dgTMatrix") 
+  temp <- get_eta(X@address, as.integer(row.idx-1), beta, beta.T@i, beta.T@j)
+  eta <- sweep(temp, 2, alpha, "+")
+  # dimnames(eta) <- list(c(1:nrow(eta)), round(object$lambda, digits = 4))
+  
+  return(eta)
+}
+
 #' @method coef biglasso
 #' @rdname predict.biglasso
 #' @export
@@ -110,3 +145,32 @@ coef.biglasso <- function(object, lambda, which = 1:length(object$lambda), drop
   else beta <- object$beta[,which,drop=FALSE]
   if (drop) return(drop(beta)) else return(beta)
 }
+
+#' @method coef mbiglasso
+#' @rdname predict.biglasso
+#' @export
+#'
+coef.mbiglasso <- function(object, lambda, which = 1:length(object$lambda), intercept = TRUE, ...) {
+  nclass = length(object$beta)
+  beta = list()
+  if(intercept) col.idx = 1:nrow(object$beta[[1]])
+  else col.idx = 2:nrow(object$beta[[1]])
+  if (!missing(lambda)) {
+    ind <- approx(object$lambda,seq(object$lambda),lambda)$y
+    l <- floor(ind)
+    r <- ceiling(ind)
+    w <- ind %% 1
+    for(class in 1:nclass) {
+      beta_class = (1-w)*(object$beta[[class]])[col.idx,l,drop=FALSE] + w*(object$beta[[class]])[col.idx,r,drop=FALSE]
+      colnames(beta_class) <- round(lambda,4)
+      beta = append(beta, beta_class)
+    }
+  }
+  else{
+    for(class in 1:nclass) {
+      beta_class = (object$beta[[class]])[col.idx,which,drop=FALSE]
+      beta = append(beta, beta_class)
+    }
+  } 
+  return(beta)
+}
\ No newline at end of file
